about summary refs log tree commit diff stats
path: root/modules/home.legacy
diff options
context:
space:
mode:
Diffstat (limited to '')
-rwxr-xr-xmodules/by-name/xd/xdg/scripts/url-handler.sh (renamed from modules/home.legacy/conf/xdg/url_handler.sh)7
-rw-r--r--modules/home.legacy/conf/default.nix2
-rw-r--r--modules/home.legacy/conf/mail/accounts/soispha.nix4
-rw-r--r--modules/home.legacy/conf/xdg/default.nix59
-rw-r--r--modules/home.legacy/conf/xdg/xdg_vars.nix29
-rw-r--r--modules/home.legacy/conf/ytcc/default.nix11
-rw-r--r--modules/home.legacy/conf/ytcc/ytcc.conf37
-rw-r--r--modules/home.legacy/pkgs/default.nix5
8 files changed, 8 insertions, 146 deletions
diff --git a/modules/home.legacy/conf/xdg/url_handler.sh b/modules/by-name/xd/xdg/scripts/url-handler.sh
index f15df384..d1c8277d 100755
--- a/modules/home.legacy/conf/xdg/url_handler.sh
+++ b/modules/by-name/xd/xdg/scripts/url-handler.sh
@@ -2,7 +2,7 @@
 
 project="$({
     tskm projects list
-    echo nvim zathura
+    printf "%s\n" nvim zathura
 } | rofi -sep "$(printf "\n")" -dmenu)"
 
 if [ "$project" = "nvim" ]; then
@@ -10,9 +10,10 @@ if [ "$project" = "nvim" ]; then
 elif [ "$project" = "zathura" ]; then
     zathura "$1"
 elif [ "$project" ]; then
-    firefox -P "$project" "$1"
+    tskm open project "$project" "$1"
 else
-    notify-send "(URL HANDLER) No project selected" && exit 1
+    notify-send "(URL HANDLER) No project selected"
+    exit 1
 fi
 
 # vim: ft=sh
diff --git a/modules/home.legacy/conf/default.nix b/modules/home.legacy/conf/default.nix
index 5a10951c..767039c6 100644
--- a/modules/home.legacy/conf/default.nix
+++ b/modules/home.legacy/conf/default.nix
@@ -27,7 +27,5 @@
     ./starship
     ./swayidle
     ./tridactyl
-    ./xdg
-    ./ytcc
   ];
 }
diff --git a/modules/home.legacy/conf/mail/accounts/soispha.nix b/modules/home.legacy/conf/mail/accounts/soispha.nix
index 6e3e6228..11634ab3 100644
--- a/modules/home.legacy/conf/mail/accounts/soispha.nix
+++ b/modules/home.legacy/conf/mail/accounts/soispha.nix
@@ -33,11 +33,11 @@
   #   };
   # };
   smtp = {
-    host = "mail.foss-syndicate.org";
+    host = "mail.vhack.eu";
     port = 465;
   };
   imap = {
-    host = "mail.foss-syndicate.org";
+    host = "mail.vhack.eu";
     port = 993;
   };
   jmap = {
diff --git a/modules/home.legacy/conf/xdg/default.nix b/modules/home.legacy/conf/xdg/default.nix
deleted file mode 100644
index 9751d806..00000000
--- a/modules/home.legacy/conf/xdg/default.nix
+++ /dev/null
@@ -1,59 +0,0 @@
-{
-  pkgs,
-  lib,
-  ...
-}: let
-  url_handler = pkgs.writeShellApplication {
-    name = "url-handler";
-    text = builtins.readFile ./url_handler.sh;
-    inheritPath = false;
-    runtimeInputs = [
-      pkgs.rofi
-      pkgs.libnotify
-      pkgs.zathura
-      pkgs.tskm
-    ];
-  };
-in {
-  imports = [
-    ./xdg_vars.nix
-  ];
-
-  xdg = {
-    mimeApps = {
-      enable = true;
-      defaultApplications = {
-        "application/pdf" = ["url_handler.desktop"];
-        "application/x-pdf" = ["url_handler.desktop"];
-
-        "text/html" = ["url_handler.desktop"];
-        "text/xml" = ["url_handler.desktop"];
-        "x-scheme-handler/http" = ["url_handler.desktop"];
-        "x-scheme-handler/https" = ["url_handler.desktop"];
-        "x-scheme-handler/about" = ["url_handler.desktop"];
-        "x-scheme-handler/unknown" = ["url_handler.desktop"];
-      };
-    };
-    desktopEntries = {
-      url-handler = {
-        name = "url-handler";
-        genericName = "Web Browser";
-        exec = "${lib.getExe url_handler} %u";
-        terminal = false;
-        categories = [
-          "Application"
-          "Network"
-          "WebBrowser"
-        ];
-        mimeType = [
-          "text/html"
-          "text/xml"
-          "x-scheme-handler/http"
-          "x-scheme-handler/https"
-          "x-scheme-handler/about"
-          "x-scheme-handler/unknown"
-        ];
-      };
-    };
-  };
-}
diff --git a/modules/home.legacy/conf/xdg/xdg_vars.nix b/modules/home.legacy/conf/xdg/xdg_vars.nix
deleted file mode 100644
index aa2f30d4..00000000
--- a/modules/home.legacy/conf/xdg/xdg_vars.nix
+++ /dev/null
@@ -1,29 +0,0 @@
-{config, ...}: let
-  inherit (config.xdg) dataHome;
-in {
-  # FIXME: Move these options in relevant modules, that are connected to their software.
-  #        <2024-10-21>
-
-  # Variables that only have to be set because special applications fail to set reasonable
-  # defaults (mostly understandable because of backwards-compatibility, but yeah)
-  home.sessionVariables = {
-    CARGO_HOME = "${dataHome}/cargo";
-    GRADLE_USER_HOME = "${dataHome}/gradle";
-
-    #_JAVA_OPTIONS = lib.concatStringsSep " " [
-    #        ''-Djava.util.prefs.userRoot="${config.xdg.configHome}/java"''
-    #        ''-Djavafx.cachedir="${config.xdg.cacheHome}/openjfx"''
-    #      ];
-    #GOPATH = "${config.xdg.dataHome}/go";
-    #GTK2_RC_FILES = "${config.xdg.configHome}/gtk-2.0/gtkrc";
-    #RUSTUP_HOME = "${config.xdg.dataHome}/rustup";
-    #NPM_CONFIG_USERCONFIG = "${config.xdg.configHome}/npm/npmrc";
-    #NUGET_PACKAGES = "${config.xdg.cacheHome}/NuGetPackages";
-    #XAUTHORITY = "${config.xdg.stateHome}/Xauthority";
-    #COMPDUMPFILE = "${config.xdg.dataHome}/zsh/.zcompdump}";
-    #IPYTHONDIR = "${config.xdg.configHome}/ipython";
-    #PARALLEL_HOME = "${config.xdg.configHome}/parallel";
-    #STACK_XDG = "1";
-    #WINEPREFIX = "${config.xdg.dataHome}/wine";
-  };
-}
diff --git a/modules/home.legacy/conf/ytcc/default.nix b/modules/home.legacy/conf/ytcc/default.nix
deleted file mode 100644
index 87300ec1..00000000
--- a/modules/home.legacy/conf/ytcc/default.nix
+++ /dev/null
@@ -1,11 +0,0 @@
-{
-  config,
-  pkgs,
-  ...
-}: {
-  xdg.configFile."ytcc/ytcc.conf".source = pkgs.substituteAll {
-    src = ./ytcc.conf;
-    download_dir = "${config.xdg.userDirs.download}/ytcc";
-    xdg_data_home = config.xdg.dataHome;
-  };
-}
diff --git a/modules/home.legacy/conf/ytcc/ytcc.conf b/modules/home.legacy/conf/ytcc/ytcc.conf
deleted file mode 100644
index 289843ad..00000000
--- a/modules/home.legacy/conf/ytcc/ytcc.conf
+++ /dev/null
@@ -1,37 +0,0 @@
-[ytcc]
-download_dir = @download_dir@
-mpv_flags = --really-quiet --ytdl --ytdl-format=bestvideo[height<=?1080]+bestaudio/best --speed=2.7
-download_subdirs = true
-order_by = playlists:asc, publish_date:desc
-video_attrs = id, title, publish_date, duration, playlists
-playlist_attrs = name, url, tags, reverse
-db_path = @xdg_data_home@/ytcc/ytcc.db
-date_format = %Y-%m-%d
-max_update_fail = 5
-max_update_backlog = 20
-age_limit = 0
-
-[tui]
-alphabet = sdfervghnuiojkl
-default_action = play_video
-
-[theme]
-prompt_download_audio = 2
-prompt_download_video = 4
-prompt_play_audio = 2
-prompt_play_video = 4
-prompt_mark_watched = 1
-table_alternate_background = 245
-plain_label_text = 244
-
-[youtube_dl]
-format = bestvideo[height<=?1080]+bestaudio/best
-output_template = %(title)s.%(ext)s
-ratelimit = 0
-retries = 0
-subtitles = off
-thumbnail = true
-skip_live_stream = true
-merge_output_format = mkv
-max_duration = 0
-restrict_filenames = false
diff --git a/modules/home.legacy/pkgs/default.nix b/modules/home.legacy/pkgs/default.nix
index 31942f0d..fd8b811a 100644
--- a/modules/home.legacy/pkgs/default.nix
+++ b/modules/home.legacy/pkgs/default.nix
@@ -85,7 +85,8 @@ with pkgs; let
 
     SystemUpdate = [
       fupdate # Generic update tool.
-      update-sys # System update tool (meant to slot into `fupdate`).
+      fupdate-sys # System update tool (meant to slot into `fupdate`).
+      fupdate-flake # Nix flake update tool (meant to slot into `fupdate`).
     ];
 
     FileListers = [
@@ -93,8 +94,6 @@ with pkgs; let
       fd # Simple, fast and user-friendly alternative to find
       ripgrep # A search tool that combines the usability of ag with the raw speed of grep
       file # Show information about a file
-      ll # Wrapper around `lf` to automatically change the path
-      lm # Wrapper around `ll` to automatically cd to the last accessed path
     ];
 
     Programming = {